@@ -34,7 +34,7 @@ class FolioApi():
     #### Class Methods ####
 
     # Constructor method
-    def __init__(self, filepath: str='src/config/config.ini'):
+    def __init__(self, filepath: str='config/config.ini'):
         self.setupConfig(filepath)
         if not self.okapi_token:
             _okapi_token = self.getToken()
